@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef CONFIG_H
-#define CONFIG_H
+#pragma once
 
 #include <Module.h>
 
@@ -24,5 +23,3 @@ Q_SIGNALS:
 private:
     D_PTR;
 };
-
-#endif // CONFIG_H
